@@ -16,10 +16,16 @@ SUFFIXES = {
     '.JPG': '.jpg',
     '.PNG': '.png',
 }
+# TODO: Use `convert` (ImageMagick) to convert some images to JPEG
+# See https://github.com/python-pillow/Pillow/issues/2806
+SUFFIX_IMAGES = [
+    '.heic',  # HEIF
+]
 SUFFIX_VIDEO_ARGS = {
     '.mov': ['-movflags', 'use_metadata_tags'],
     '.mpg': [],
 }
+SUFFIX_TRACKS = '.gpx'
 LSUFFIX_GZIP = [
     ['.gpx', '.gz'],
 ]
@@ -48,6 +54,9 @@ def __main__():
 
     for p in args.basedir.iterdir():
         if p.is_file():
+            # Remove executable bits from files
+            # TODO: No need to use subprocess for this
+            subprocess.run(['chmod', '-x', str(p)])
             if p.suffix in SUFFIXES:
                 new_name = p.with_suffix(SUFFIXES[p.suffix])
                 if not new_name.exists():
@@ -103,6 +112,9 @@ def __main__():
                         new_name.unlink()
                 else:
                     new_name = None
+            elif p.suffix.lower() == SUFFIX_TRACKS:
+                # TODO: Split inner `<trk>` into separate files: /gpx/trk
+                pass
 
 
 if __name__ == '__main__':
