@@ -6,6 +6,7 @@ import argparse
 import logging
 import mimetypes
 import os
+import subprocess
 
 from . import utils
 from . import thumbnail
@@ -300,8 +301,18 @@ def __main__():
     parser.add_argument('--template', type=Path,
                         action='append', default=[],
                         help='Extra template location to use. Overrides other locations')
-    parser.add_argument('--static-location', default='',
-                        help='The URL (absolute or relative) where the files in `static` are provided. Defaults to being relative to the HTML location')
+    parser.add_argument('--static-location', default=os.environ.get('PYPUBLISH_STATIC_LOCATION', ''),
+                        help='''
+                        The URL (absolute or relative) where the files in `static` are provided.
+                        Defaults to being relative to the HTML location.
+                        Override with "$PYPUBLISH_STATIC_LOCATION" [%(default)s].
+                        ''')
+    parser.add_argument('--static-path', default=os.environ.get('PYPUBLISH_STATIC_PATH', None),
+                        help='''
+                        The filesystem location where the files in `static` are exposed.
+                        Synchronizes the files if given.
+                        Override with "$PYPUBLISH_STATIC_PATH" [%(default)s].
+                        ''')
     parser.add_argument('--no-thumb-play-overlay', dest='thumb_overlay',
                         action='store_const', default=True, const=None,
                         help='Thumbnails: Hide the "play" overlay image. Defaults to an internal one, based on size')
@@ -320,6 +331,16 @@ def __main__():
         'PIL',
     ])
 
+    # Static Files
+    logger.debug('App Static Files: %s', utils.STATIC_INSTALL)
+    if args.static_path is not None:
+        static_path = Path(args.static_path)
+        static_path.mkdir(exist_ok=True)
+        logger.debug('- Static Folder: %s', static_path.resolve())
+        if not utils.STATIC_INSTALL.samefile(static_path):
+            logger.debug('- Syncing...')
+            subprocess.check_output(['rsync', '-qru', f'{utils.STATIC_INSTALL}/', f'{static_path}/'])
+
     Image.init()  # Initialize PIL
     mimetypes.init()  # Initialize MIME types
 
