@@ -142,10 +142,12 @@ if sys.version_info >= (3, 9):
     TEMPLATES_LOCATIONS.append(
         res.files('pythumbnailer').__enter__() / 'templates',  # Current module Folder
     )
+    STATIC_INSTALL = Path(res.files('pythumbnailer').__enter__() / 'static')
 else:
     TEMPLATES_LOCATIONS.append(
         Path(__file__).resolve().parent / 'templates',  # Current installation Folder
     )
+    STATIC_INSTALL = Path(__file__).resolve().parent / 'static'
 
 
 def template_locations(*override: Path):
